## 温州民间借贷利率

接口：wz_index

描述：温州民间借贷利率，即温州指数

限量：不限量，一次可取全部指标全部历史数据

积分：用户需要积攒2000积分可调取，具体请参阅积分获取办法

数据来源：温州指数网





注：

温州指数 ，即温州民间融资综合利率指数，该指数及时反映民间金融交易活跃度和交易价格。该指数样板数据主要采集于四个方面：由温州市设立的几百家企业测报点，把各自借入的民间资本利率通过各地方金融办不记名申报收集起来；对各小额贷款公司借出的利率进行加权平均；融资性担保公司如典当行在融资过程中的利率，由温州经信委和商务局负责测报；民间借贷服务中心的实时利率。这些利率进行加权平均，就得出了“温州指数”。它是温州民间融资利率的风向标。2012年12月7日，温州指数正式对外发布。







输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| date | str | N | 日期 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期 |
| comp_rate | float | Y | 温州民间融资综合利率指数 (%，下同) |
| center_rate | float | Y | 民间借贷服务中心利率 |
| micro_rate | float | Y | 小额贷款公司放款利率 |
| cm_rate | float | Y | 民间资本管理公司融资价格 |
| sdb_rate | float | Y | 社会直接借贷利率 |
| om_rate | float | Y | 其他市场主体利率 |
| aa_rate | float | Y | 农村互助会互助金费率 |
| m1_rate | float | Y | 温州地区民间借贷分期限利率（一月期） |
| m3_rate | float | Y | 温州地区民间借贷分期限利率（三月期） |
| m6_rate | float | Y | 温州地区民间借贷分期限利率（六月期） |
| m12_rate | float | Y | 温州地区民间借贷分期限利率（一年期） |
| long_rate | float | Y | 温州地区民间借贷分期限利率（长期） |

接口用法

```python
pro = ts.pro_api()

df = pro.wz_index(start_date='20180101', end_date='20190401')
```

数据样例

```python
date  comp_rate  center_rate  micro_rate  cm_rate  sdb_rate  om_rate  \
0    20180102      15.05        16.58       14.74     15.0     14.43    22.99   
```